==> haskell-shelly-1.11.0-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-shelly.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 shelly
version:              1.11.0
visibility:           public
id:                   shelly-1.11.0-7i4cxL22QU4A1kdRsNmb2O
key:                  shelly-1.11.0-7i4cxL22QU4A1kdRsNmb2O
license:              BSD-3-Clause
maintainer:           Andreas Abel
author:               Greg Weber, Petr Rockai
homepage:             https://github.com/gregwebs/Shelly.hs
synopsis:             shell-like (systems) programming in Haskell
description:
    Shelly provides convenient systems programming in Haskell,
    similar in spirit to POSIX shells. Shelly:

    * is aimed at convenience and getting things done rather than
    being a demonstration of elegance,

    * has detailed and useful error messages,

    * maintains its own environment, making it thread-safe.

    Shelly is originally forked from the Shellish package.

    See the shelly-extra package for additional functionality.

    An overview is available in the README: <https://github.com/gregwebs/Shelly.hs/blob/master/README.md>

category:             Development
abi:                  2a9386a144a11fdd3124cfb5f64e5500
exposed:              True
exposed-modules:      Shelly Shelly.Lifted Shelly.Pipe Shelly.Unix
hidden-modules:       Shelly.Base Shelly.Find Shelly.Directory
import-dirs:          /usr/lib/ghc-9.4.8/site-local/shelly-1.11.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/shelly-1.11.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/shelly-1.11.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-shelly
hs-libraries:         HSshelly-1.11.0-7i4cxL22QU4A1kdRsNmb2O
depends:
    async-2.2.5-GOsAYCd2Rtz3HW1WOZa8a9 base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.7.1
    enclosed-exceptions-1.0.3-Gn0aVMZ2NW75gXfh7GaYhE exceptions-0.10.5
    filepath-1.4.2.2 lifted-async-0.10.2.7-7D4TIpOSn6aDRU4m5QisdP
    lifted-base-0.2.3.12-9TPkxssbXW4DumNwTYyXCT
    monad-control-1.0.3.1-5d82eYalKzB1lBE27TbkgK mtl-2.2.2
    process-1.6.18.0 text-2.0.2 time-1.12.2 transformers-0.5.6.2
    transformers-base-0.4.6-411BkTw86QqB7n6xMIgJ6x
    unix-compat-0.7.4-HkeMBjDm0rZC7ERiJ32kv5

haddock-interfaces:   /usr/share/doc/haskell-shelly/html/shelly.haddock
haddock-html:         /usr/share/doc/haskell-shelly/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-shelly-1.11.0-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-shelly.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 shelly
version:              1.11.0
visibility:           public
id:                   shelly-1.11.0-4me7vm54Ra4JNdBPvgqRkA
key:                  shelly-1.11.0-4me7vm54Ra4JNdBPvgqRkA
license:              BSD-3-Clause
maintainer:           Andreas Abel
author:               Greg Weber, Petr Rockai
homepage:             https://github.com/gregwebs/Shelly.hs
synopsis:             shell-like (systems) programming in Haskell
description:
    Shelly provides convenient systems programming in Haskell,
    similar in spirit to POSIX shells. Shelly:

    * is aimed at convenience and getting things done rather than
    being a demonstration of elegance,

    * has detailed and useful error messages,

    * maintains its own environment, making it thread-safe.

    Shelly is originally forked from the Shellish package.

    See the shelly-extra package for additional functionality.

    An overview is available in the README: <https://github.com/gregwebs/Shelly.hs/blob/master/README.md>

category:             Development
abi:                  de28ec15526a1587505058b9574dec83
exposed:              True
exposed-modules:      Shelly Shelly.Lifted Shelly.Pipe Shelly.Unix
hidden-modules:       Shelly.Base Shelly.Find Shelly.Directory
import-dirs:          /usr/lib/ghc-9.4.8/site-local/shelly-1.11.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/shelly-1.11.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/shelly-1.11.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-shelly
hs-libraries:         HSshelly-1.11.0-4me7vm54Ra4JNdBPvgqRkA
depends:
    async-2.2.5-KIpQ4bNDIRO6XYT7v2y3ZE base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.7.1
    enclosed-exceptions-1.0.3-LFdSgxhO8xF6T0CWHNwJUE exceptions-0.10.5
    filepath-1.4.2.2 lifted-async-0.10.2.7-3wNmfSoMDKNHpRLgIqnrfR
    lifted-base-0.2.3.12-AELrIAGexwKTexJUnanLP
    monad-control-1.0.3.1-ADBy113jPZx6EyMvvTxyI9 mtl-2.2.2
    process-1.6.18.0 text-2.0.2 time-1.12.2 transformers-0.5.6.2
    transformers-base-0.4.6-5fKXdbxww34Jppu8NGc4jg
    unix-compat-0.7.4-HSgadBBXSpB6KNshGA8sWV

haddock-interfaces:   /usr/share/doc/haskell-shelly/html/shelly.haddock
haddock-html:         /usr/share/doc/haskell-shelly/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
